@@ -51,6 +51,10 @@ def line(frame,stxy,endxy,colors,size):
     frame=cv2.line(frame, stxy, endxy,color(colors), size)
     return frame
 
+def text(frame,text,xy,font_size,colors,size):
+    frame=cv2.putText(frame,  text, xy, cv2.FONT_HERSHEY_SIMPLEX, font_size, color(colors),size)
+    return frame
+
 def find_camid():
     print('开始测试摄像头,请耐心等待...')
     a=[]
