@@ -3,6 +3,11 @@ Blockly.Python.pins = function() {
     return [code, Blockly.Python.ORDER_ATOMIC];
   };
 
+  Blockly.Python.pins_ad = function() {
+    var code = this.getFieldValue('PIN');
+    return [code, Blockly.Python.ORDER_ATOMIC];
+  };
+
 Blockly.Python.inout_highlow = function () {
     // Boolean values HIGH and LOW.
     var code = (this.getFieldValue('BOOL') == 'HIGH') ? 'HIGH' : 'LOW';
@@ -143,3 +148,31 @@ Blockly.Python['serial_get_settings'] = function () {
     return [code,Blockly.Python.ORDER_ATOMIC];
 };
 
+Blockly.Python['GPIO_AD_init'] = function () {
+    Blockly.Python.definitions_['AD_init'] = 'from Mx import PCF8591';
+    var code ='PCF8591.init()'
+    return [code,Blockly.Python.ORDER_ATOMIC];
+};
+
+Blockly.Python['GPIO_AD_init'] = function () {
+    Blockly.Python.definitions_['AD_init'] = 'from Mx import PCF8591';
+    var code ='PCF8591.init()'
+    return [code,Blockly.Python.ORDER_ATOMIC];
+};
+
+Blockly.Python['GPIO_AD_IN'] = function () {
+    Blockly.Python.definitions_['AD_init'] = 'from Mx import PCF8591';
+    var name =  Blockly.Python.valueToCode(this, 'NAME', Blockly.Python.ORDER_ATOMIC);
+    var pin =  Blockly.Python.valueToCode(this, 'PIN', Blockly.Python.ORDER_ATOMIC);
+    var code =name+'.read("'+pin+'")'
+    return [code,Blockly.Python.ORDER_ATOMIC];
+};
+
+Blockly.Python['GPIO_AD_OUT'] = function () {
+    Blockly.Python.definitions_['AD_init'] = 'from Mx import PCF8591';
+    var name =  Blockly.Python.valueToCode(this, 'NAME', Blockly.Python.ORDER_ATOMIC);
+    var val =  Blockly.Python.valueToCode(this, 'VAR', Blockly.Python.ORDER_ATOMIC);
+    var code =name+'.write('+val+')\n'
+    return code;
+};
+
