@@ -57,6 +57,23 @@ Blockly.Python.python_opencv_resize = function(a) {
     return [code,Blockly.Python.ORDER_ATOMIC];
 }
 
+Blockly.Python.python_opencv_rotating = function(a) {
+    Blockly.Python.definitions_['Opencv'] = 'import cv2';
+    var img = Blockly.Python.valueToCode(this,'NAME',Blockly.Python.ORDER_ASSIGNMENT);
+    var v = this.getFieldValue('NUM')
+    if(v==90){
+        var s='cv2.ROTATE_90_CLOCKWISE'
+    }
+    else if(v==180){
+        var s='cv2.ROTATE_180'
+    }
+    else if(v==270){
+        var s='cv2.ROTATE_90_COUNTERCLOCKWISE'
+    }
+    var code = 'cv2.rotate('+img+','+s+')';
+    return [code,Blockly.Python.ORDER_ATOMIC];
+}
+
 Blockly.Python.python_opencv_color_block= function(a) {
     Blockly.Python.definitions_['Opencv'] = 'import cv2';
     Blockly.Python.definitions_['Mxopencv'] = 'from Mx import mxopencv';
@@ -118,7 +135,7 @@ Blockly.Python.python_opencv_line=function(a){
 Blockly.Python.opencv_find_camid=function(a){
     Blockly.Python.definitions_['Opencv'] = 'import cv2';
     Blockly.Python.definitions_['Mxopencv'] = 'from Mx import mxopencv';
-    var code = 'mxopencv.find_camid()'
+    var code = 'mxopencv.find_camid()\n'
     return code;
 }
 
@@ -133,4 +150,22 @@ Blockly.Python.python_opencv_text=function(a){
     var size = Blockly.Python.valueToCode(this,'SIZE',Blockly.Python.ORDER_ASSIGNMENT);
     var code = 'mxopencv.text('+img+','+text+','+xy+','+font_size+',"'+color+'",'+size+')\n'
     return code;
+}
+
+Blockly.Python.python_opencv_cap_setHW=function(a){
+    Blockly.Python.definitions_['Opencv'] = 'import cv2';
+    var cap = Blockly.Python.valueToCode(this,'NAME',Blockly.Python.ORDER_ASSIGNMENT);
+    var w = Blockly.Python.valueToCode(this,'W',Blockly.Python.ORDER_ASSIGNMENT);
+    var h = Blockly.Python.valueToCode(this,'H',Blockly.Python.ORDER_ASSIGNMENT);
+    var code = cap+".set(cv2.CAP_PROP_FRAME_WIDTH, "+w+")\n"+
+               cap+".set(cv2.CAP_PROP_FRAME_HEIGHT, "+h+")\n"
+    return code;
+}
+
+Blockly.Python.python_opencv_FULLSCREEN=function(a){
+    Blockly.Python.definitions_['Opencv'] = 'import cv2';
+    var name = Blockly.Python.valueToCode(this,'NAME',Blockly.Python.ORDER_ASSIGNMENT);
+    var code = "cv2.namedWindow("+name+",cv2.WND_PROP_FULLSCREEN)\n"+
+                "cv2.setWindowProperty("+name+", cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN)\n"
+    return code;
 }
\ No newline at end of file
