@@ -67,6 +67,9 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'AI_category': {
         'colour': "#009966",
       },
+      'SArduino_category': {
+        'colour': "#fb7b04",
+      },
       'GUI_category': {
         'colour': "#00a8a8",
       },
@@ -119,6 +122,11 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'colourSecondary':"#fff",
       'colourTertiary':"#009966"
     }, 
+    'SArduino_blocks': {
+      'colourPrimary': "#fb7b04",
+      'colourSecondary':"#fff",
+      'colourTertiary':"#fb7b04"
+    }, 
     'sensor_blocks': {
       'colourPrimary': "#bc954e",
       'colourSecondary':"#fff",
@@ -180,7 +188,7 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'blackBackground': '#333'
     }
   });
-
+var SArduino_zt=false
 var blocklyArea = document.getElementById('blocklyArea');
 var blocklyDiv = document.getElementById('blocklyDiv');
 var codesapce = document.getElementById('monaco');
@@ -359,6 +367,8 @@ function upfile(){
     chatSocket.send(JSON.stringify({'msg':'stop'}))
   }
 }
+var connect_SArduino = document.getElementById('connect_SArduino');
+connect_SArduino.style.visibility = 'hidden';
 var slider1,slider2,slider3,slider4,slider5,slider5,slider6
 var h_min=0
 var s_min=0
@@ -419,7 +429,7 @@ window.onload = function () {      /*chushihua*/
   chatSocket.onopen = function () {
     console.log(' ' + 'websocket connection success')
     chatSocket.send(JSON.stringify({'msg':'loadclock'}))
-    add('已与树莓派端建立连接')
+    add('已建立连接')
     c=true
     con_btn.style.color='#00aa1c'
     con_btn_ui.className='fa fa-link'
@@ -427,11 +437,11 @@ window.onload = function () {      /*chushihua*/
   };
   chatSocket.onerror = function () {
     console.error(' ' + 'websocket connection error')
-    add('树莓派端连接失败')
+    add('连接失败')
   };
   chatSocket.onclose = function (e) {
     console.error(' ' + 'websocket closed unexpectedly 状态码:' + e.code);
-    add('与树莓派端已断开连接,请重新连接...'+' ' + 'websocket closed unexpectedly 状态码:' + e.code)
+    add('已断开连接,请重新连接...'+' ' + 'websocket closed unexpectedly 状态码:' + e.code)
     con_btn.style.color='#F44336'
     con_btn_ui.className='fa fa-chain-broken'
     c=false
@@ -444,6 +454,29 @@ window.onload = function () {      /*chushihua*/
     add(data['data'])
     console.log(data)
     }
+    else if(data['msg']=='com_msg'){
+      add_com(data['data'])
+      if(data['rust']=='connect_ok'){
+        SArduino_zt=true
+        connect_SArduino.style.visibility = 'visible';
+        document.getElementById('com_i').innerHTML='<i class="fa fa-check-circle-o fa-2x" aria-hidden="true" style="color: green;margin-left: 10px;"></i>'
+        document.getElementById('bt-connect-com').innerText='断开'
+        document.getElementById('bt-connect-com').style.background='red'
+      }
+      if(data['rust']=='connect_del'){
+        SArduino_zt=false
+        connect_SArduino.style.visibility = 'hidden';
+        document.getElementById('com_i').innerHTML='<i class="fa fa-times-circle-o fa-2x" aria-hidden="true" style="color: red;margin-left: 10px;"></i>'
+        document.getElementById('bt-connect-com').innerText='连接'
+        document.getElementById('bt-connect-com').style.background=''
+      }
+      console.log(data)
+    }
+    else if(data['msg']=='com_err_msg'){
+      console.log(data)
+      addcom_err(data['data'])
+      connect_SArduino.style.visibility = 'hidden';
+    }
     else if (data['msg']=='run_err_msg'){
     adderr(data['data'])
     console.log(data)
@@ -530,7 +563,7 @@ window.onload = function () {      /*chushihua*/
     }
   });
   
-  instance=$('.e-scrollbar-box-2,.e-scrollbar-box-1').overlayScrollbars({
+  instance=$('.e-scrollbar-box-1,.e-scrollbar-box-2,.e-scrollbar-box-3').overlayScrollbars({
     className       : "os-theme-dark",
     resize          : "none",
     sizeAutoCapable : true,
@@ -560,6 +593,11 @@ function clears() {
   var oP = document.querySelector("#cmd_ > div.os-padding > div > div")
   oP.innerHTML = '';
 
+}
+function clears_com() {
+  var oP = document.querySelector("#com_cmd > div.os-padding > div > div")
+  oP.innerHTML = '';
+
 }
 
 function clearss() {
@@ -606,6 +644,21 @@ function add(txt) {
     oP.appendChild(oPs)
     instance[0].scroll({ y : "100%"  });
 }
+function add_com(txt) {
+  list_num = list_num+1
+  list_nums = list_nums+1
+  if(list_num>300){
+  clears()
+  list_num=0
+  list_nums=0
+}	
+  var oP = document.querySelector("#com_cmd > div.os-padding > div > div")
+  var oPs =document.createElement("p");
+  var num= list_nums
+  oPs.innerHTML = "<div class='d1'><div class='d2'><a class='num'>"+num+"</a></div><div class='d3'><a class='d4'>"+txt+"</a></div></div>";
+  oP.appendChild(oPs)
+  instance[2].scroll({ y : "100%"  });
+}
 function adderr(txt) {
   list_num = list_num+1
   list_nums = list_nums+1
@@ -633,7 +686,21 @@ function addpip_err(txt) {
   var num= list_nums
   oPs.innerHTML = "<div class='d1-err'><div class='d2-err'><a class='num'>"+num+"</a></div><div class='d3-err'><a class='d4-err'>"+txt+"</a></div></div>";
   oP.appendChild(oPs)
-  instance[1].scroll({ y : "100%"  });
+  instance[2].scroll({ y : "100%"  });
+}
+function addcom_err(txt) {
+  list_num = list_num+1
+  list_nums = list_nums+1
+  if(list_num>2000){
+  clearss()
+  list_num=0
+}	
+  var oP = document.querySelector("#com_cmd > div.os-padding > div > div")
+  var oPs =document.createElement("p");
+  var num= list_nums
+  oPs.innerHTML = "<div class='d1-err'><div class='d2-err'><a class='num'>"+num+"</a></div><div class='d3-err'><a class='d4-err'>"+txt+"</a></div></div>";
+  oP.appendChild(oPs)
+  instance[2].scroll({ y : "100%"  });
 }
 
 function save(){
@@ -826,7 +893,7 @@ resizeOpacity: 1,
 });
   $("#Rexample_content").PopupWindow({
     height      : 450,
-    width       : 600,
+    width       : 800,
     title       : "例程",
     autoOpen    : false,
     buttons         : {
@@ -849,7 +916,7 @@ resizeOpacity: 1,
   });
 
   $("#Modelexample_content").PopupWindow({
-    height      : 450,
+    height      : 460,
     width       : 900,
     title       : "模型社区",
     autoOpen    : false,
@@ -896,7 +963,63 @@ resizeOpacity: 1,
   resizeOpacity: 1,
   });
 
+  $("#Modelinfo_content").PopupWindow({
+    height      : 450,
+    width       : 900,
+    title       : "模型信息",
+    autoOpen    : false,
+    buttons         : {
+      close           : true,          // Boolean
+      maximize        : false,          // Boolean
+      collapse        : false,          // Boolean
+      minimize        : false,          // Boolean
+  },
+  buttonsTexts        : {
+    close               : "退出",
+    maximize            : "最大化",
+    minimize            : "最小化",
+    collapse            : "搜索",
+  }, 
+  draggable           : true,
+  nativeDrag          : true,
+  dragOpacity         : 1,
+  resizable:false,
+  resizeOpacity: 1,
+  });
 
+  $("#SArduino_content").PopupWindow({
+    height      : 500,
+    width       : 900,
+    title       : "SArduino",
+    autoOpen    : false,
+    buttons         : {
+      close           : true,          // Boolean
+      maximize        : false,          // Boolean
+      collapse        : false,          // Boolean
+      minimize        : false,          // Boolean
+  },
+  buttonsTexts        : {
+    close               : "退出",
+    maximize            : "最大化",
+    minimize            : "最小化",
+    collapse            : "搜索",
+  }, 
+  draggable           : true,
+  nativeDrag          : true,
+  dragOpacity         : 1,
+  resizable:false,
+  resizeOpacity: 1,
+  });
+  var com_list
+  $("#SArduino_content").on("open.popupwindow", function(event,data){com_list=self.setInterval(function(){
+    sx_com()
+  },500);})
+  $("#SArduino_content").on("close.popupwindow", function(event,data){clearInterval(com_list)})
+
+  $("#Arduinomodel").on("click", function(event){
+    $("#SArduino_content").PopupWindow("open");
+    SArduino_get_list()
+  });
   $("#filemodel").on("click", function(event){
       $("#file_content").PopupWindow("open");
       file_list()
@@ -960,16 +1083,16 @@ function pipinstall(){
   list_num_pip=0
   list_nums_pip=0
   var pip_install_name=document.getElementById('pip_install_name').value;
-  chatSocket.send(JSON.stringify({'msg':'pip_install','name':pip_install_name,'url':'https://pypi.doubanio.com/simple'}))
+  install_ku(pip_install_name)
 }
 
 function connect_server(){
   if(c==false){
-    add('开始连接树莓派端')
+    add('开始连接')
     chatSocket = new WebSocket('ws://' + window.location.host + '/ws/run/');
     chatSocket.onopen = function () {
       console.log(' ' + 'websocket connection success')
-      add('已与树莓派端建立连接')
+      add('已建立连接')
       con_btn.style.color='#00aa1c'
       con_btn_ui.className='fa fa-link'
       con_btn.disable=false
@@ -977,11 +1100,11 @@ function connect_server(){
     };
     chatSocket.onerror = function () {
       console.error(' ' + 'websocket connection error')
-      add('树莓派端连接失败')
+      add('连接失败')
     };
     chatSocket.onclose = function (e) {
       console.error(' ' + 'websocket closed unexpectedly 状态码:' + e.code);
-      add('与树莓派端已断开连接,请重新连接...'+' ' + 'websocket closed unexpectedly 状态码:' + e.code)
+      add('已断开连接,请重新连接...'+' ' + 'websocket closed unexpectedly 状态码:' + e.code)
       con_btn.style.color='#F44336'
       con_btn_ui.className='fa fa-chain-broken'
       document.querySelector("body > div:nth-child(16) > div > div.tippy-tooltip-content").innerHTML='重新连接'
@@ -1420,14 +1543,15 @@ function pip_list(){
     }
     )
   $("#pip-table").tabulator("setData",[
-    {id:1, name:"opencv", col:"opencv库", arr:'arrch64/windows',cheese:re('opencv-python')},
-    {id:2, name:"pyqt5",  col:"Pyqt5", arr:'arrch64/windows',cheese:re('pyqt5')},
-    {id:3, name:"Tensorflow 2.8.0",  col:"Tensorflow", arr:'arrch64/windows',cheese:re('tensorflow==2.8.0')},
-    {id:4, name:"Mediapipe",  col:"Mediapipe", arr:'arrch64/windwos',cheese:re('mediapipe')},
-    {id:5, name:"sounddevice",  col:"录音与播放音乐", arr:'arrch64/windows',cheese:re('sounddevice')},
-    {id:6, name:"SoundFile",  col:"音频文件操作", arr:'arrch64/windows',cheese:re('SoundFile')},
-    {id:7, name:"librosa",  col:"用于音乐和音频分析的python包", arr:'arrch64/windows',cheese:re('librosa')},
-    {id:8, name:"hcsr04sensor",  col:"超声波传感器的依赖库", arr:'arrch64',cheese:re('hcsr04sensor')},
+    {id:1, name:"opencv", col:"opencv库", arr:'win/Liunx/rpi',cheese:re('opencv-python')},
+    {id:2, name:"pyqt5",  col:"Pyqt5", arr:'win/Liunx/rpi',cheese:re('pyqt5')},
+    {id:3, name:"Tensorflow 2.8.0",  col:"Tensorflow", arr:'win/Liunx/rpi',cheese:re('tensorflow==2.8.0')},
+    {id:4, name:"Pytorch",  col:"Pytorch", arr:'win/Liunx/rpi',cheese:re('torch')},
+    {id:5, name:"Mediapipe",  col:"Mediapipe", arr:'win/Liunx/rpi',cheese:re('mediapipe')},
+    {id:6, name:"sounddevice",  col:"录音与播放音乐", arr:'win/Liunx/rpi',cheese:re('sounddevice')},
+    {id:7, name:"SoundFile",  col:"音频文件操作", arr:'win/Liunx/rpi',cheese:re('SoundFile')},
+    {id:8, name:"librosa",  col:"用于音乐和音频分析的python包", arr:'win/Liunx/rpi',cheese:re('librosa')},
+    {id:9, name:"hcsr04sensor",  col:"超声波传感器的依赖库", arr:'rpi',cheese:re('hcsr04sensor')},
   ]);
 }
 
@@ -1435,7 +1559,7 @@ function c_list(){
   $("#c-table").tabulator({columns:[
     {title:"名称", field:"name", sortable:true,align:'center',sorter:"string", width:'30%'},
     {title:"简介", field:"col", sorter:"string", sortable:false, width:'50%'},
-    {title:"操作", field:"cheese", sortable:true,align:'center',width:'20%'},
+    {title:"操作", field:"cheese", sortable:true,align:'center',width:'17%'},
     ],
     height:'300px',
     }
@@ -1448,27 +1572,28 @@ function c_list(){
     {id:5, name:"发送网络请求(带参数)",  col:"发送网络请求获取指定城市当日天气数据",cheese:ce('5')},
     {id:6, name:"创建桌面应用程序",  col:"PyQt5创建GUI",cheese:ce('6')},
     {id:7, name:"创建桌面应用程序(交互)",  col:"PyQt5创建交互GUI",cheese:ce('7')},
-    {id:8, name:"调用百度AI",  col:"调用被百度AI进行图像识别",cheese:ce('8')},
-    {id:9, name:"调用百度AI_2",  col:"调用被百度AI进行语音识别",cheese:ce('9')},
-    {id:10, name:"调用百度AI_3",  col:"调用被百度AI进行语音合成",cheese:ce('10')},
-    {id:11, name:"MediaPipe-1", col:"使用MediaPipe进行人脸检测",cheese:ce('11')},
-    {id:12, name:"MediaPipe-2",  col:"使用MediaPipe进行面网",cheese:ce('12')},
-    {id:13, name:"MediaPipe-3",  col:"使用MediaPipe进行手部检测",cheese:ce('13')},
-    {id:14, name:"MediaPipe-4",  col:"使用MediaPipe进行人体姿态检测",cheese:ce('14')},
-    {id:15, name:"目标识别",  col:"进行模型推理、目标识别",cheese:ce('15')},
-    {id:16, name:"图像分类",  col:"进行模型推理、图像分类",cheese:ce('16')},
-
+    {id:8, name:"色块识别",  col:"进行色块识别",cheese:ce('18')},
+    {id:9, name:"调用百度AI",  col:"调用被百度AI进行图像识别",cheese:ce('8')},
+    {id:10, name:"调用百度AI_2",  col:"调用被百度AI进行语音识别",cheese:ce('9')},
+    {id:11, name:"调用百度AI_3",  col:"调用被百度AI进行语音合成",cheese:ce('10')},
+    {id:12, name:"MediaPipe-1", col:"使用MediaPipe进行人脸检测",cheese:ce('11')},
+    {id:13, name:"MediaPipe-2",  col:"使用MediaPipe进行面网",cheese:ce('12')},
+    {id:14, name:"MediaPipe-3",  col:"使用MediaPipe进行手部检测",cheese:ce('13')},
+    {id:15, name:"MediaPipe-3-1",  col:"使用MediaPipe进行手部检测,并连线（由顺德区龙江实验学校张楚彬老师贡献）",cheese:ce('17')},
+    {id:16, name:"MediaPipe-4",  col:"使用MediaPipe进行人体姿态检测",cheese:ce('14')},
+    {id:17, name:"目标识别",  col:"进行模型推理、目标识别",cheese:ce('15')},
+    {id:18, name:"图像分类",  col:"进行模型推理、图像分类",cheese:ce('16')},
   ]);
 }
-
+var model_lists
 function model_list(){
   $("#model-table").tabulator({columns:[
-    {title:"名称", field:"name", sortable:true,sorter:"string", width:'15%'},
-    {title:"简介", field:"info", sorter:"string", sortable:false, width:'20%'},
-    {title:"类型", field:"star", sortable:true,width:'15%'},
-    {title:"文件大小(M)", field:"file_size", sortable:true,width:'10%'},
+    {title:"名称", field:"name", sortable:true,sorter:"string",align:'center', width:'15%'},
+    {title:"简介", field:"info", sorter:"string", sortable:false, width:'30%'},
+    {title:"类型", field:"star", sortable:true,align:'center',width:'10%'},
+    {title:"大小(M)", field:"file_size", sortable:true,align:'center',width:'10%'},
     {title:"上传时间", field:"publish", sortable:true,width:'15%'},
-    {title:"发布人", field:"people", sortable:true,width:'12%'},
+    {title:"发布人", field:"people", sortable:true,align:'center',width:'10%'},
     {title:"操作", field:"down", sortable:true,align:'center',width:'10%'},
     ],
     height:'300px',
@@ -1496,6 +1621,7 @@ function model_list(){
             autoclose: 1500,
             style: 'success'
           });
+          model_lists=datas.data
           $("#model-table").tabulator("setData",datas.data)
         }
         }
@@ -1543,8 +1669,9 @@ function re(name){
 }
 function install_ku(name){
   console.log(name)
+  yuan=document.getElementById("pip-yuan").selectedIndex;
   addpip('开始安装 '+name+' ,请保持网络畅通。')
-  chatSocket.send(JSON.stringify({'msg':'install_ku','name':name}))
+  chatSocket.send(JSON.stringify({'msg':'install_ku','name':name,'pipyuan':yuan}))
 }
 
 var rec=false
@@ -1728,6 +1855,21 @@ function fabumodel(){
 }
 
 function downModel(id,name){
+  $("#Modelinfo_content").PopupWindow("open");
+  document.getElementById('downdiv').innerHTML='<button class="button button-action" style="margin-top: 5px;" onclick="downModel_f('+id+',\''+name+'\')">下载模型</button>'
+  console.log(model_lists)
+  datas=model_lists.find(function(data){
+    return data.file_id==id
+  })
+  document.getElementById('mo1').innerHTML=datas.name
+  document.getElementById('mo2').innerHTML=datas.star
+  document.getElementById('mo3').innerHTML=datas.info
+  document.getElementById('mo4').innerHTML=datas.publish
+  document.getElementById('mo5').innerHTML=datas.people
+  document.getElementById('mo6').innerHTML=datas.file_size
+}
+
+function downModel_f(id,name){
   $.ajax({
     url:"./downModel",
     type:"GET",
@@ -1740,6 +1882,7 @@ function downModel(id,name){
           autoclose: 1500,
           style: 'success'
         });
+        $("#Modelinfo_content").PopupWindow("close");
       }
       else{
         spop({
@@ -1749,7 +1892,74 @@ function downModel(id,name){
           style: 'error'
         });
       }
-
       }
     })
-}
\ No newline at end of file
+}
+
+function SArduino_get_list(){
+  $.ajax({
+    url:"./SArduino_get_list",
+    type:"GET",
+    data:{},
+    success:function(data){
+      datas=JSON.parse(data)
+      if(datas.msg=='ok'){
+        html=''
+        for(da of datas.data){
+          html +='<option value="'+da.port+'">'+da.desc+'</option>'
+        }
+        document.getElementById('usb_list').innerHTML=html
+      }
+      else{
+        document.getElementById('arduinomsg').innerHTML=datas.data
+      }
+      }
+    })
+}
+
+function content_com(){
+  if(SArduino_zt==false){
+  com=document.getElementById("usb_list")
+  index=com.selectedIndex;//2：取到选中项的索引
+  val=com.options[index].value;
+  chatSocket.send(JSON.stringify({'msg':'connect_com','com':val}))
+  }
+  else{
+  chatSocket.send(JSON.stringify({'msg':'del_com','com':val}))
+  }
+}
+
+function to_com_msg(){
+  val=document.getElementById('com_msg').value
+  if(SArduino_zt){
+    chatSocket.send(JSON.stringify({'msg':'to_com_msg','com':val}))
+    add_com("<< "+val)
+  }
+  else{
+    addcom_err('串口未连接,请先连接串口设备')
+  }
+}
+
+function sx_com(){
+  $.ajax({
+    url:"./SArduino_get_list",
+    type:"GET",
+    data:{},
+    success:function(data){
+      datas=JSON.parse(data)
+      console.log(datas)
+      if(datas.msg=='ok'){
+        html=''
+        for(da of datas.data){
+          html +='<option value="'+da.port+'">'+da.desc+'</option>'
+        }
+        document.getElementById('usb_list').innerHTML=html
+      }
+      else{
+        document.getElementById('arduinomsg').innerHTML=datas.data
+      }
+      }
+    })
+}
+
+
